@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2003 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2004 Peter Simonsson <psn@linux.se>
+    SPDX-FileCopyrightText: 2003 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2004 Peter Simonsson <psn@linux.se>
 */
 
 #include <QObject>
@@ -15,8 +10,6 @@
 #ifndef SCRIPTLAUNCHER_H
 #define SCRIPTLAUNCHER_H
 
-
-
 class ScriptLauncher : public QObject
 {
     Q_OBJECT
@@ -27,11 +20,15 @@ class ScriptLauncher : public QObject
 
         static QString scriptPath(const QString& script);
 
+    public Q_SLOTS:
+        void launchScript(int connectionId, const QString& target, const QString& parameter);
+
     Q_SIGNALS:
         void scriptNotFound(const QString& name);
         void scriptExecutionError(const QString& name);
 
-    public Q_SLOTS:
-        void launchScript(int connectionId, const QString& target, const QString& parameter);
+    private:
+        Q_DISABLE_COPY(ScriptLauncher)
 };
+
 #endif
